@@ -1,5 +1,6 @@
 #' Query Chemical Identifier Resolver
 #' @import xml2
+#' @importFrom utils URLencode
 #'
 #' @param identifier character; chemical identifier.
 #' @param representation character; what representation of the identifier should
@@ -109,6 +110,7 @@
 cir_query <- function(identifier, representation = 'smiles', resolver = NULL,
                       first = FALSE, verbose = TRUE, ...){
   foo <- function(identifier, representation, resolver, first, verbose) {
+    identifier <- URLencode(identifier)
     baseurl <- "https://cactus.nci.nih.gov/chemical/structure"
     qurl <- paste(baseurl, identifier, representation, 'xml', sep = '/')
     if (!is.null(resolver)) {
