@@ -39,13 +39,20 @@ test_that("is.inchikey() returns correct results", {
 })
 
 
+test_that("is.smiles() returns correct results", {
+  skip_on_cran()
 
-# test_that("is.smiles() returns correct results", {
-#   skip_on_cran()
-#
-#   expect_true(is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl'))
-#   expect_false(is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)ClWWX'))
-#   expect_error(is.smiles(c('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl', 'Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl')))
-# })
+  expect_true(is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl'))
+  expect_false(is.smiles('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)ClWWX'))
+  expect_error(is.smiles(c('Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl', 'Clc1ccc(cc1)C(c2ccc(Cl)cc2)C(Cl)(Cl)Cl')))
+})
+
+test_that("extr_num() returns correct results", {
+  skip_on_cran()
+
+  expect_equal(extr_num("Melting Pt : -44.6 deg C"), -44.6)
+  expect_equal(extr_num("Melting Pt : 44.6 deg C"), 44.6)
+  expect_equal(extr_num("Melting Pt : 446 deg C"), 446)
+})
 
 
